<?php

namespace Litecms\Bapsplan\Policies;

use Litepie\User\Contracts\UserPolicy;
use Litecms\Bapsplan\Models\Bapplan;

class BapplanPolicy
{

    /**
     * Determine if the given user can view the bapplan.
     *
     * @param UserPolicy $user
     * @param Bapplan $bapplan
     *
     * @return bool
     */
    public function view(UserPolicy $user, Bapplan $bapplan)
    {
        if ($user->canDo('bapsplan.bapplan.view') && $user->isAdmin()) {
            return true;
        }

        return $bapplan->user_id == user_id() && $bapplan->user_type == user_type();
    }

    /**
     * Determine if the given user can create a bapplan.
     *
     * @param UserPolicy $user
     * @param Bapplan $bapplan
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('bapsplan.bapplan.create');
    }

    /**
     * Determine if the given user can update the given bapplan.
     *
     * @param UserPolicy $user
     * @param Bapplan $bapplan
     *
     * @return bool
     */
    public function update(UserPolicy $user, Bapplan $bapplan)
    {
        if ($user->canDo('bapsplan.bapplan.edit') && $user->isAdmin()) {
            return true;
        }

        return $bapplan->user_id == user_id() && $bapplan->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given bapplan.
     *
     * @param UserPolicy $user
     * @param Bapplan $bapplan
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Bapplan $bapplan)
    {
        return $bapplan->user_id == user_id() && $bapplan->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given bapplan.
     *
     * @param UserPolicy $user
     * @param Bapplan $bapplan
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Bapplan $bapplan)
    {
        if ($user->canDo('bapsplan.bapplan.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given bapplan.
     *
     * @param UserPolicy $user
     * @param Bapplan $bapplan
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Bapplan $bapplan)
    {
        if ($user->canDo('bapsplan.bapplan.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
